# pyostrap
Python wrapper for Biostrap API

## Installing Pyostrap and Supported Versions

Pyostrap is available on PyPI:

```console
$ pip install pyostrap
```

Pyostrap officially supports Python 3.12+.